"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from acuvity.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class ScanexternaluserTypedDict(TypedDict):
    r"""ScanExternalUser holds the information about the remote user for a ScanRequest."""

    claims: List[str]
    r"""List of claims extracted from the user query."""
    name: str
    r"""The name of the external user."""


class Scanexternaluser(BaseModel):
    r"""ScanExternalUser holds the information about the remote user for a ScanRequest."""

    claims: List[str]
    r"""List of claims extracted from the user query."""

    name: str
    r"""The name of the external user."""
